@@ -172,6 +172,7 @@ void DownloadItem::downloadProgress(qint64 received, qint64 total)
     m_total = total;
 
     updateDownloadInfo(m_currSpeed, m_received, m_total);
+    emit progressChanged(m_currSpeed, m_received, m_total);
 }
 
 int DownloadItem::progress()
@@ -363,6 +364,21 @@ void DownloadItem::openFolder()
 #endif
 }
 
+QUrl DownloadItem::url() const
+{
+    return m_downUrl;
+}
+
+QString DownloadItem::path() const
+{
+    return m_path;
+}
+
+QString DownloadItem::fileName() const
+{
+    return m_fileName;
+}
+
 DownloadItem::~DownloadItem()
 {
     delete ui;
