@@ -115,14 +115,13 @@ OpenSearchEngine::OpenSearchEngine(QObject* parent)
     A destructor.
 */
 OpenSearchEngine::~OpenSearchEngine()
-{
-}
+= default;
 
 QString OpenSearchEngine::parseTemplate(const QString &searchTerm, const QString &searchTemplate)
 {
     QString language = QLocale().name();
     // Simple conversion to RFC 3066.
-    language = language.replace(QLatin1Char('_'), QLatin1Char('-'));
+    language.replace(QLatin1Char('_'), QLatin1Char('-'));
 
     QString result = searchTemplate;
     result.replace(QLatin1String("{count}"), QLatin1String("20"));
@@ -222,7 +221,7 @@ void OpenSearchEngine::setSearchUrlTemplate(const QString &searchUrlTemplate)
 QUrl OpenSearchEngine::searchUrl(const QString &searchTerm) const
 {
     if (m_searchUrlTemplate.isEmpty()) {
-        return QUrl();
+        return {};
     }
 
     QUrl retVal = QUrl::fromEncoded(parseTemplate(searchTerm, m_searchUrlTemplate).toUtf8());
@@ -243,7 +242,7 @@ QUrl OpenSearchEngine::searchUrl(const QString &searchTerm) const
 QByteArray OpenSearchEngine::getPostData(const QString &searchTerm) const
 {
     if (m_searchMethod != QLatin1String("post")) {
-        return QByteArray();
+        return {};
     }
 
     QUrl retVal = QUrl("http://foo.bar");
@@ -308,7 +307,7 @@ QUrl OpenSearchEngine::suggestionsUrl(const QString &searchTerm) const
     }
 
     if (m_suggestionsUrlTemplate.isEmpty()) {
-        return QUrl();
+        return {};
     }
 
     QUrl retVal = QUrl::fromEncoded(parseTemplate(searchTerm, m_suggestionsUrlTemplate).toUtf8());
@@ -432,7 +431,7 @@ void OpenSearchEngine::loadImage() const
 
 void OpenSearchEngine::imageObtained()
 {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    auto* reply = qobject_cast<QNetworkReply*>(sender());
 
     if (!reply) {
         return;
@@ -448,7 +447,7 @@ void OpenSearchEngine::imageObtained()
     }
 
     m_image.loadFromData(response);
-    emit imageChanged();
+    Q_EMIT imageChanged();
 }
 
 /*!
@@ -480,7 +479,7 @@ void OpenSearchEngine::setImage(const QImage &image)
     }
 
     m_image = image;
-    emit imageChanged();
+    Q_EMIT imageChanged();
 }
 
 /*!
@@ -540,7 +539,7 @@ QByteArray OpenSearchEngine::getSuggestionsParameters()
     Parameters::const_iterator end = m_suggestionsParameters.constEnd();
     Parameters::const_iterator i = m_suggestionsParameters.constBegin();
     for (; i != end; ++i) {
-        parameters.append(i->first + QLatin1String("=") + i->second);
+        parameters.append(i->first + QLatin1Char('=') + i->second);
     }
 
     QByteArray data = parameters.join(QLatin1String("&")).toUtf8();
@@ -576,7 +575,7 @@ void OpenSearchEngine::requestSuggestions(const QString &searchTerm)
         Parameters::const_iterator end = m_suggestionsParameters.constEnd();
         Parameters::const_iterator i = m_suggestionsParameters.constBegin();
         for (; i != end; ++i) {
-            parameters.append(i->first + QLatin1String("=") + i->second);
+            parameters.append(i->first + QLatin1Char('=') + i->second);
         }
 
         QByteArray data = parameters.join(QLatin1String("&")).toUtf8();
@@ -613,7 +612,7 @@ void OpenSearchEngine::requestSearchResults(const QString &searchTerm)
         Parameters::const_iterator end = m_searchParameters.constEnd();
         Parameters::const_iterator i = m_searchParameters.constBegin();
         for (; i != end; ++i) {
-            parameters.append(i->first + QLatin1String("=") + i->second);
+            parameters.append(i->first + QLatin1Char('=') + i->second);
         }
 
         data = parameters.join(QLatin1String("&")).toUtf8();
@@ -644,10 +643,12 @@ void OpenSearchEngine::suggestionsObtained()
 
     QStringList out;
 
-    foreach (const QVariant &v, list.at(1).toList())
+    const auto items = list.at(1).toList();
+    for (const QVariant &v : items) {
         out.append(v.toString());
+    }
 
-    emit suggestions(out);
+    Q_EMIT suggestions(out);
 }
 
 /*!
