@@ -22,7 +22,6 @@
 #include "iconprovider.h"
 #include "mainapplication.h"
 #include "opensearchreader.h"
-#include "opensearchengine.h"
 #include "settings.h"
 #include "qzsettings.h"
 #include "webview.h"
@@ -119,7 +118,7 @@ SearchEngine SearchEnginesManager::engineForShortcut(const QString &shortcut)
         return returnEngine;
     }
 
-    foreach (const Engine &en, m_allEngines) {
+    for (const Engine &en : qAsConst(m_allEngines)) {
         if (en.shortcut == shortcut) {
             returnEngine = en;
             break;
@@ -166,12 +165,11 @@ void SearchEnginesManager::restoreDefaults()
     duck.suggestionsUrl = "https://ac.duckduckgo.com/ac/?q=%s&type=list";
 
     Engine sp;
-    sp.name = "StartPage";
+    sp.name = "Startpage";
     sp.icon = QIcon(":/icons/sites/startpage.png");
-    sp.url = "https://startpage.com/do/search";
-    sp.postData = "query=%s&cat=web&language=english";
+    sp.url = "https://www.startpage.com/sp/search?query=%s&cat=web&pl=opensearch";
     sp.shortcut = "sp";
-    sp.suggestionsUrl = "https://startpage.com/cgi-bin/csuggest?output=json&lang=english&query=%s";
+    sp.suggestionsUrl = "https://www.startpage.com/osuggestions?q=%s";
 
     Engine wiki;
     wiki.name = "Wikipedia (en)";
@@ -194,7 +192,7 @@ void SearchEnginesManager::restoreDefaults()
 
     m_defaultEngine = duck;
 
-    emit enginesChanged();
+    Q_EMIT enginesChanged();
 }
 
 // static
@@ -211,13 +209,13 @@ QIcon SearchEnginesManager::iconForSearchEngine(const QUrl &url)
 
 void SearchEnginesManager::engineChangedImage()
 {
-    OpenSearchEngine* engine = qobject_cast<OpenSearchEngine*>(sender());
+    auto* engine = qobject_cast<OpenSearchEngine*>(sender());
 
     if (!engine) {
         return;
     }
 
-    foreach (Engine e, m_allEngines) {
+    for (Engine e : qAsConst(m_allEngines)) {
         if (e.name == engine->name() &&
             e.url.contains(engine->searchUrl("%s").toString()) &&
             !engine->image().isNull()
@@ -226,7 +224,7 @@ void SearchEnginesManager::engineChangedImage()
             if (index != -1) {
                 m_allEngines[index].icon = QIcon(QPixmap::fromImage(engine->image()));
 
-                emit enginesChanged();
+                Q_EMIT enginesChanged();
 
                 delete engine;
                 break;
@@ -251,7 +249,7 @@ void SearchEnginesManager::addEngine(const Engine &engine)
 
     m_allEngines.append(engine);
 
-    emit enginesChanged();
+    Q_EMIT enginesChanged();
 }
 
 void SearchEnginesManager::addEngineFromForm(const QVariantMap &formData, WebView *view)
@@ -280,7 +278,7 @@ void SearchEnginesManager::addEngineFromForm(const QVariantMap &formData, WebVie
     query.addQueryItem(inputName, QSL("SEARCH"));
 
     const QVariantList &inputs = formData.value(QSL("inputs")).toList();
-    foreach (const QVariant &pair, inputs) {
+    for (const QVariant &pair : inputs) {
         const QVariantList &list = pair.toList();
         if (list.size() != 2)
             continue;
@@ -379,7 +377,7 @@ void SearchEnginesManager::replyFinished()
 {
     qApp->restoreOverrideCursor();
 
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    auto* reply = qobject_cast<QNetworkReply*>(sender());
     if (!reply) {
         return;
     }
@@ -424,7 +422,7 @@ void SearchEnginesManager::setActiveEngine(const Engine &engine)
     }
 
     m_activeEngine = engine;
-    emit activeEngineChanged();
+    Q_EMIT activeEngineChanged();
 }
 
 void SearchEnginesManager::setDefaultEngine(const SearchEnginesManager::Engine &engine)
@@ -436,7 +434,7 @@ void SearchEnginesManager::setDefaultEngine(const SearchEnginesManager::Engine &
     }
 
     m_defaultEngine = engine;
-    emit defaultEngineChanged();
+    Q_EMIT defaultEngineChanged();
 }
 
 void SearchEnginesManager::removeEngine(const Engine &engine)
@@ -456,7 +454,7 @@ void SearchEnginesManager::removeEngine(const Engine &engine)
     query.exec();
 
     m_allEngines.remove(index);
-    emit enginesChanged();
+    Q_EMIT enginesChanged();
 }
 
 void SearchEnginesManager::setAllEngines(const QVector<Engine> &engines)
@@ -464,7 +462,7 @@ void SearchEnginesManager::setAllEngines(const QVector<Engine> &engines)
     ENSURE_LOADED;
 
     m_allEngines = engines;
-    emit enginesChanged();
+    Q_EMIT enginesChanged();
 }
 
 QVector<SearchEngine> SearchEnginesManager::allEngines()
@@ -496,7 +494,7 @@ void SearchEnginesManager::saveSettings()
     QSqlQuery query(SqlDatabase::instance()->database());
     query.exec("DELETE FROM search_engines");
 
-    foreach (const Engine &en, m_allEngines) {
+    for (const Engine &en : qAsConst(m_allEngines)) {
         query.prepare("INSERT INTO search_engines (name, icon, url, shortcut, suggestionsUrl, suggestionsParameters, postData) VALUES (?, ?, ?, ?, ?, ?, ?)");
         query.addBindValue(en.name);
         query.addBindValue(iconToBase64(en.icon));
