@@ -21,6 +21,7 @@
 #include "webpage.h"
 
 #include <QUrlQuery>
+#include <QtWebEngineWidgetsVersion>
 
 QString Scripts::setupWebChannel()
 {
@@ -145,11 +146,8 @@ QString Scripts::setupWindowObject()
                           "    console.warn('NOT IMPLEMENTED: IsSearchProviderInstalled()');"
                           "    return false;"
                           "};"
-                          "window.external = external;"
-                          "window.print = function() {"
-                          "    window.location = 'falkon:PrintPage';"
-                          "};"
-                          "})()");
+                          "window.external = external;");
+           source += QL1S("})()");
 
     return source;
 }
@@ -229,7 +227,7 @@ QString Scripts::completeFormData(const QByteArray &data)
                           "        var type = input.type.toLowerCase();"
                           "        if (type != 'text' && type != 'password' && type != 'email')"
                           "            continue;"
-                          "        if (input.name == key) {"
+                          "        if (input.name == key && input.name != '') {"
                           "            input.value = val;"
                           "            input.dispatchEvent(new Event('change'));"
                           "        }"
@@ -329,3 +327,19 @@ QString Scripts::getFormData(const QPointF &pos)
 
     return source.arg(pos.x()).arg(pos.y());
 }
+
+QString Scripts::scrollToAnchor(const QString &anchor)
+{
+    QString source = QL1S("(function() {"
+                          "var e = document.getElementById(\"%1\");"
+                          "if (!e) {"
+                          "    var els = document.querySelectorAll(\"[name='%1']\");"
+                          "    if (els.length)"
+                          "        e = els[0];"
+                          "}"
+                          "if (e)"
+                          "    e.scrollIntoView();"
+                          "})()");
+
+    return source.arg(anchor);
+}
